@@ -1,4 +1,4 @@
-/*      $Id: xfwm4_plugin.c 20688 2006-04-02 18:47:41Z olivier $
+/*      $Id: xfwm4_plugin.c 22293 2006-07-08 12:36:25Z olivier $
  
         This program is free software; you can redistribute it and/or modify
         it under the terms of the GNU General Public License as published by
@@ -64,7 +64,7 @@ struct _TitleButton
     gchar *stock_icon;
 };
 
-static TitleButton title_button[] = {
+static const TitleButton title_button[] = {
     {"O", N_("Menu"), "gtk-index"},
     {"T", N_("Stick"), "gtk-add"},
     {"S", N_("Shade"), "gtk-goto-top"},
@@ -74,7 +74,7 @@ static TitleButton title_button[] = {
 };
 
 
-MenuTmpl dbl_click_values[] = {
+static const MenuTmpl dbl_click_values[] = {
     {N_("Shade window"), "shade"},
     {N_("Hide window"), "hide"},
     {N_("Maximize window"), "maximize"},
@@ -82,7 +82,7 @@ MenuTmpl dbl_click_values[] = {
     {NULL, NULL}
 };
 
-MenuTmpl title_align_values[] = {
+static const MenuTmpl title_align_values[] = {
     {N_("Left"), "left"},
     {N_("Center"), "center"},
     {N_("Right"), "right"},
@@ -124,6 +124,22 @@ sensitive_cb (GtkWidget * widget, gpointer user_data)
     gtk_widget_set_sensitive (widget, (gboolean) GPOINTER_TO_INT (user_data));
 }
 
+static GtkWidget *
+create_check_button_with_mnemonic (const gchar * label)
+{
+    GtkWidget *check_button;
+    GtkWidget *label_widget;
+
+    label_widget = gtk_label_new_with_mnemonic (label);
+    gtk_label_set_line_wrap (GTK_LABEL (label_widget), TRUE);
+    gtk_widget_show (label_widget);
+
+    check_button = gtk_check_button_new ();
+    gtk_container_add (GTK_CONTAINER (check_button), label_widget);
+
+    return check_button;
+}
+
 static void
 delete_motion_indicator (GtkWidget * widget)
 {
@@ -627,7 +643,7 @@ create_layout_buttons (gchar * layout, gpointer user_data)
 }
 
 static GtkWidget *
-create_option_menu_box (MenuTmpl template[], guint size, gchar * display_label, gchar * value,
+create_option_menu_box (const MenuTmpl template[], guint size, gchar * display_label, gchar * value,
     GCallback handler, gpointer user_data)
 {
     GtkWidget *hbox;
@@ -644,28 +660,20 @@ create_option_menu_box (MenuTmpl template[], guint size, gchar * display_label,
     gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
     gtk_widget_show (hbox);
 
-    omenu = gtk_option_menu_new ();
+    omenu = gtk_combo_box_new_text ();
     gtk_box_pack_start (GTK_BOX (hbox), omenu, TRUE, TRUE, 0);
     gtk_widget_show (omenu);
 
-    menu = gtk_menu_new ();
-    gtk_option_menu_set_menu (GTK_OPTION_MENU (omenu), menu);
-    gtk_widget_show (menu);
-
     for (n = 0; n < size; n++)
     {
-        item = gtk_menu_item_new_with_mnemonic (_(template[n].label));
-        gtk_widget_show (item);
-        gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
+        gtk_combo_box_append_text (GTK_COMBO_BOX (omenu), _(template[n].label));
 
         if (strcmp (value, template[n].action) == 0)
-            gtk_option_menu_set_history (GTK_OPTION_MENU (omenu), n);
-
-        g_object_set_data (G_OBJECT (item), "user-data", template[n].action);
-
-        g_signal_connect (G_OBJECT (item), "activate", G_CALLBACK (handler), user_data);
+            gtk_combo_box_set_active (GTK_COMBO_BOX (omenu), n);
     }
 
+    g_signal_connect (G_OBJECT (omenu), "changed", G_CALLBACK (handler), user_data);
+
     return (vbox);
 }
 
@@ -1292,14 +1300,12 @@ static void
 cb_dblclick_action_value_changed (GtkWidget * widget, gpointer user_data)
 {
     McsPlugin *mcs_plugin = (McsPlugin *) user_data;
-    const gchar *action;
+    gint active;
 
-    action = (const gchar *) g_object_get_data (G_OBJECT (widget), "user-data");
+    g_free (dbl_click_action);
+    active = gtk_combo_box_get_active (GTK_COMBO_BOX (widget));
+    dbl_click_action = g_strdup (dbl_click_values[active].action);
 
-    if (dbl_click_action)
-        g_free (dbl_click_action);
-
-    dbl_click_action = g_strdup (action);
     mcs_manager_set_string (mcs_plugin->manager, "Xfwm/DblClickAction", CHANNEL1, dbl_click_action);
     mcs_manager_notify (mcs_plugin->manager, CHANNEL1);
     xfwm4_plugin_write_options (mcs_plugin);
@@ -1309,14 +1315,12 @@ static void
 cb_title_align_value_changed (GtkWidget * widget, gpointer user_data)
 {
     McsPlugin *mcs_plugin = (McsPlugin *) user_data;
-    const gchar *action;
+    gint active;
 
-    action = (const gchar *) g_object_get_data (G_OBJECT (widget), "user-data");
+    g_free (title_align);
+    active = gtk_combo_box_get_active (GTK_COMBO_BOX (widget));
+    title_align = g_strdup (title_align_values[active].action);
 
-    if (title_align)
-        g_free (title_align);
-
-    title_align = g_strdup (action);
     mcs_manager_set_string (mcs_plugin->manager, "Xfwm/TitleAlign", CHANNEL1, title_align);
     mcs_manager_notify (mcs_plugin->manager, CHANNEL1);
     xfwm4_plugin_write_options (mcs_plugin);
@@ -1418,23 +1422,18 @@ create_dialog (McsPlugin * mcs_plugin)
 
     dialog->mcs_plugin = mcs_plugin;
 
-    dialog->xfwm4_dialog = gtk_dialog_new ();
+    dialog->xfwm4_dialog = xfce_titled_dialog_new ();
     gtk_window_set_title (GTK_WINDOW (dialog->xfwm4_dialog), _("Window Manager"));
     gtk_dialog_set_has_separator (GTK_DIALOG (dialog->xfwm4_dialog), FALSE);
+    gtk_window_set_icon_name(GTK_WINDOW(dialog->xfwm4_dialog), "xfwm4");
 
     dialog->font_selection = NULL;
 
-    gtk_window_set_icon (GTK_WINDOW (dialog->xfwm4_dialog), mcs_plugin->icon);
-
     dialog->click_focus_radio_group = NULL;
 
     dialog->dialog_vbox = GTK_DIALOG (dialog->xfwm4_dialog)->vbox;
     gtk_widget_show (dialog->dialog_vbox);
 
-    dialog->dialog_header = xfce_create_header (mcs_plugin->icon, _("Window Manager Preferences"));
-    gtk_widget_show (dialog->dialog_header);
-    gtk_box_pack_start (GTK_BOX (dialog->dialog_vbox), dialog->dialog_header, FALSE, TRUE, 0);
-
     notebook = gtk_notebook_new ();
     gtk_container_set_border_width (GTK_CONTAINER (notebook), BORDER + 1);
     gtk_widget_show (notebook);
@@ -1611,7 +1610,7 @@ create_dialog (McsPlugin * mcs_plugin)
         !click_to_focus);
 
     dialog->focus_new_check =
-        gtk_check_button_new_with_mnemonic (_("Automatically give focus to newly created windows"));
+        create_check_button_with_mnemonic (_("Automatically give focus to newly created windows"));
     gtk_widget_show (dialog->focus_new_check);
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (dialog->focus_new_check), focus_new);
 
@@ -1627,7 +1626,7 @@ create_dialog (McsPlugin * mcs_plugin)
     gtk_box_pack_start (GTK_BOX (vbox_page), frame, TRUE, TRUE, 0);
 
     dialog->raise_on_focus_check =
-        gtk_check_button_new_with_mnemonic (
+        create_check_button_with_mnemonic (
         _("Automatically raise windows when they receive focus"));
     gtk_widget_show (dialog->raise_on_focus_check);
     gtk_box_pack_start (GTK_BOX (vbox), dialog->raise_on_focus_check, FALSE, FALSE, 0);
@@ -1672,7 +1671,7 @@ create_dialog (McsPlugin * mcs_plugin)
     gtk_widget_set_sensitive (dialog->raise_delay_scale, focus_raise);
 
     dialog->click_raise_check =
-        gtk_check_button_new_with_mnemonic (
+        create_check_button_with_mnemonic (
         _("Raise window when clicking inside application window"));
     gtk_widget_show (dialog->click_raise_check);
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (dialog->click_raise_check), raise_on_click);
@@ -1700,13 +1699,13 @@ create_dialog (McsPlugin * mcs_plugin)
     gtk_box_pack_start (GTK_BOX (vbox_page), frame, TRUE, TRUE, 0);
 
     dialog->snap_to_border_check =
-        gtk_check_button_new_with_mnemonic (_("Snap windows to screen border"));
+        create_check_button_with_mnemonic (_("Snap windows to screen border"));
     gtk_widget_show (dialog->snap_to_border_check);
     gtk_box_pack_start (GTK_BOX (vbox), dialog->snap_to_border_check, FALSE, FALSE, 0);
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (dialog->snap_to_border_check), snap_to_border);
 
     dialog->snap_to_windows_check =
-        gtk_check_button_new_with_mnemonic (_("Snap windows to other windows"));
+        create_check_button_with_mnemonic (_("Snap windows to other windows"));
     gtk_widget_show (dialog->snap_to_windows_check);
     gtk_box_pack_start (GTK_BOX (vbox), dialog->snap_to_windows_check, FALSE, FALSE, 0);
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (dialog->snap_to_windows_check),
@@ -1757,7 +1756,7 @@ create_dialog (McsPlugin * mcs_plugin)
     gtk_box_pack_start (GTK_BOX (vbox_page), frame, TRUE, TRUE, 0);
 
     dialog->wrap_workspaces_check =
-        gtk_check_button_new_with_mnemonic (
+        create_check_button_with_mnemonic (
         _("Wrap workspaces when the pointer reaches a screen edge"));
     gtk_widget_show (dialog->wrap_workspaces_check);
     gtk_box_pack_start (GTK_BOX (vbox), dialog->wrap_workspaces_check, FALSE, FALSE, 0);
@@ -1765,7 +1764,7 @@ create_dialog (McsPlugin * mcs_plugin)
         wrap_workspaces);
 
     dialog->wrap_windows_check =
-        gtk_check_button_new_with_mnemonic (
+        create_check_button_with_mnemonic (
         _("Wrap workspaces when dragging a window off the screen"));
     gtk_widget_show (dialog->wrap_windows_check);
     gtk_box_pack_start (GTK_BOX (vbox), dialog->wrap_windows_check, FALSE, FALSE, 0);
@@ -1817,13 +1816,13 @@ create_dialog (McsPlugin * mcs_plugin)
     gtk_box_pack_start (GTK_BOX (vbox_page), frame, TRUE, TRUE, 0);
 
     dialog->box_resize_check =
-        gtk_check_button_new_with_mnemonic (_("Display content of windows when resizing"));
+        create_check_button_with_mnemonic (_("Display content of windows when resizing"));
     gtk_widget_show (dialog->box_resize_check);
     gtk_box_pack_start (GTK_BOX (vbox), dialog->box_resize_check, FALSE, FALSE, 0);
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (dialog->box_resize_check), !box_resize);
 
     dialog->box_move_check =
-        gtk_check_button_new_with_mnemonic (_("Display content of windows when moving"));
+        create_check_button_with_mnemonic (_("Display content of windows when moving"));
     gtk_widget_show (dialog->box_move_check);
     gtk_box_pack_start (GTK_BOX (vbox), dialog->box_move_check, FALSE, FALSE, 0);
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (dialog->box_move_check), !box_move);
@@ -1973,9 +1972,12 @@ mcs_plugin_init (McsPlugin * mcs_plugin)
 
     xfwm4_create_channel (mcs_plugin);
     mcs_plugin->plugin_name = g_strdup (PLUGIN_NAME);
-    mcs_plugin->caption = g_strdup (_("Window Manager"));
+    /* the button label in the xfce-mcs-manager dialog */
+    mcs_plugin->caption = g_strdup (Q_ ("Button Label|Window Manager"));
     mcs_plugin->run_dialog = run_dialog;
     mcs_plugin->icon = xfce_themed_icon_load ("xfwm4", 48);
+    if (G_LIKELY (mcs_plugin->icon != NULL))
+      g_object_set_data_full (G_OBJECT (mcs_plugin->icon), "mcs-plugin-icon-name", g_strdup ("xfwm4"), g_free);
     mcs_manager_notify (mcs_plugin->manager, CHANNEL1);
 
     return (MCS_PLUGIN_INIT_OK);
