@@ -25,9 +25,8 @@
 #define MIXER_RC_GROUP "mixer-plugin"
 
 /* Panel Plugin Interface */
-
 static void mixer_construct (XfcePanelPlugin *plugin);
-static void mixer_write_config(XfcePanelPlugin* plugin, gpointer user_data);
+
 
 XFCE_PANEL_PLUGIN_REGISTER_EXTERNAL(mixer_construct);
 
@@ -46,8 +45,10 @@ typedef struct
 	guint timer;
 } t_mixer;
 
+static void mixer_write_config(XfcePanelPlugin* plugin, t_mixer* mixer);
+
 GtkTooltips* tooltips; /* used by slider tiny */
-static XfceIconTheme* icontheme;
+static GtkIconTheme* icontheme;
 
 static void
 mixer_orientation_changed (XfcePanelPlugin *plugin, GtkOrientation orientation, 
@@ -117,7 +118,7 @@ response_cb(GtkDialog* dialog, gint arg1, gpointer user_data)
 
     xfce_mixer_prefbox_save_preferences (mixer->prefbox, mixer->prefs);
  
-    mixer_write_config(mixer->temp_plugin, user_data);
+    mixer_write_config(mixer->temp_plugin, mixer);
 
    
     gtk_container_remove (GTK_CONTAINER(dialog->vbox), GTK_WIDGET(mixer->prefbox));
@@ -192,10 +193,10 @@ mixer_size_changed_cb (XfcePanelPlugin *plugin, int size, t_mixer* mixer)
 static t_mixer * mixer_new(void);
 
 
-static void mixer_read_config(XfcePanelPlugin* plugin, gpointer user_data);
+static void mixer_read_config(XfcePanelPlugin* plugin, t_mixer *mixer);
 
 
-static void mixer_write_config(XfcePanelPlugin* plugin, gpointer user_data);
+static void mixer_write_config(XfcePanelPlugin* plugin, t_mixer *mixer);
 
 static void 
 mixer_construct (XfcePanelPlugin *plugin)
@@ -205,7 +206,7 @@ mixer_construct (XfcePanelPlugin *plugin)
 
     register_vcs ();
 
-    icontheme = xfce_icon_theme_get_for_screen (gtk_widget_get_screen (GTK_WIDGET (plugin)));
+    icontheme = gtk_icon_theme_get_for_screen (gtk_widget_get_screen (GTK_WIDGET (plugin)));
     tooltips = gtk_tooltips_new ();
     g_object_ref (G_OBJECT(tooltips));
     gtk_object_sink (GTK_OBJECT(tooltips));
@@ -296,16 +297,16 @@ xfce_mixer_launch_cb (GtkWidget *w, gpointer user_data)
 	GError* error;
 	gboolean internal;
 	
-	mixer = (t_mixer *) user_data;
-	if (!mixer || !mixer->prefs)
-		return;
-		
 	gchar* launcher_command;
 	gchar* device;
 	gboolean launcher_run_in_terminal;
 	gboolean launcher_use_startup_notification;
 	gchar* message;
 	
+	mixer = (t_mixer *) user_data;
+	if (!mixer || !mixer->prefs)
+		return;
+
 	launcher_command = NULL;
 	device = NULL;
 
@@ -418,8 +419,7 @@ get_status_pixbuf(gboolean broken)
 	GdkPixbuf	*pb;
 	GdkPixbuf	*pb2;
 	
-	pb = xfce_icon_theme_load_category (icontheme, XFCE_ICON_CATEGORY_SOUND, 128); /* ??? */
-	/* xfce_icon_theme_load_category */
+	pb = xfce_themed_icon_load ("xfce-sound", 128);
 	
 	if (broken) {
 		pb2 = gdk_pixbuf_copy(pb);
@@ -505,14 +505,11 @@ mixer_new(void)
 }
 
 static void
-mixer_read_config(XfcePanelPlugin* plugin, gpointer user_data)
+mixer_read_config(XfcePanelPlugin* plugin, t_mixer *mixer)
 {
 	XfceRc* rc;
 	gchar* path;
 
-	t_mixer *mixer;
-	mixer = (t_mixer *) user_data;
-  
 	if (mixer->prefs == NULL) {
 		return;
 	}
@@ -539,16 +536,13 @@ mixer_read_config(XfcePanelPlugin* plugin, gpointer user_data)
 }
 
 static void
-mixer_write_config(XfcePanelPlugin* plugin, gpointer user_data)
+mixer_write_config(XfcePanelPlugin* plugin, t_mixer* mixer)
 {
-    DBG ("Save: %s", PLUGIN_NAME);
-
 	XfceRc* rc;
 	gchar* path;
 
-	t_mixer *mixer;
-	mixer = (t_mixer *) user_data;
-	
+    DBG ("Save: %s", PLUGIN_NAME);
+
 	if (mixer->prefs == NULL) {
 		return;
 	}
