@@ -73,7 +73,6 @@ struct _Itf
     McsPlugin *mcs_plugin;
 
     GtkWidget *orage_dialog;
-    GtkWidget *dialog_header;
     GtkWidget *dialog_vbox1;
     GtkWidget *notebook;
     /* Tabs */
@@ -138,9 +137,20 @@ struct _Itf
 
 static void cb_dialog_response(GtkWidget * dialog, gint response_id)
 {
+    gchar *helpdoc;
+
     if(response_id == GTK_RESPONSE_HELP)
     {
+        /*
         xfce_exec("xfhelp4 xfce4-user-guide.html", FALSE, FALSE, NULL);
+        */
+                                                                             
+        helpdoc = g_strconcat("xfbrowser4 ", DATADIR
+                , G_DIR_SEPARATOR_S, "doc"
+                , G_DIR_SEPARATOR_S, "C"
+                , G_DIR_SEPARATOR_S, "orage.html#orage-preferences-window"
+                , NULL);
+        xfce_exec(helpdoc, FALSE, FALSE, NULL);
     }
     else
     {
@@ -245,53 +255,54 @@ static void cb_archive_file_open_button_clicked (GtkButton *button, gpointer use
 {
     Itf *itf = (Itf *) user_data;
     GtkWidget *file_chooser;
-	XfceFileFilter *filter;
+	GtkFileFilter *filter;
     gchar *rcfile;
     gchar *s; /* to avoid timing problems when updating entry */
 
     /* Create file chooser */
-    file_chooser = xfce_file_chooser_new(_("Select a file..."),
-                                        GTK_WINDOW (itf->orage_dialog),
-                                        XFCE_FILE_CHOOSER_ACTION_SAVE,
-                                        GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-                                        GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT,
-                                            NULL);
+    file_chooser = gtk_file_chooser_dialog_new(_("Select a file..."),
+            GTK_WINDOW(itf->orage_dialog),
+            GTK_FILE_CHOOSER_ACTION_SAVE,
+            GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+            GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT,
+            NULL);
     /* Add filters */
-    filter = xfce_file_filter_new();
-	xfce_file_filter_set_name(filter, _("Calendar files"));
-	xfce_file_filter_add_pattern(filter, "*.ics");
-	xfce_file_chooser_add_filter(XFCE_FILE_CHOOSER(file_chooser), filter);
-    filter = xfce_file_filter_new();
-	xfce_file_filter_set_name(filter, _("All Files"));
-	xfce_file_filter_add_pattern(filter, "*");
-	xfce_file_chooser_add_filter(XFCE_FILE_CHOOSER(file_chooser), filter);
+    filter = gtk_file_filter_new();
+	gtk_file_filter_set_name(filter, _("Calendar files"));
+	gtk_file_filter_add_pattern(filter, "*.ics");
+	gtk_file_chooser_add_filter(GTK_FILE_CHOOSER(file_chooser), filter);
+
+    filter = gtk_file_filter_new();
+	gtk_file_filter_set_name(filter, _("All Files"));
+	gtk_file_filter_add_pattern(filter, "*");
+	gtk_file_chooser_add_filter(GTK_FILE_CHOOSER(file_chooser), filter);
 
     rcfile = xfce_resource_save_location(XFCE_RESOURCE_CONFIG, ARCDIR, TRUE);
-    xfce_file_chooser_add_shortcut_folder(XFCE_FILE_CHOOSER(file_chooser)
-                , rcfile, NULL);
+    gtk_file_chooser_add_shortcut_folder(GTK_FILE_CHOOSER(file_chooser)
+            , rcfile, NULL);
 
     /* Set the archive path */
     if (archive_path && strlen(archive_path)) {
-        if (! xfce_file_chooser_set_filename(XFCE_FILE_CHOOSER(file_chooser)
-            , archive_path))
-            xfce_file_chooser_set_current_name(
-                XFCE_FILE_CHOOSER(file_chooser), ARCFILE);
+        if (! gtk_file_chooser_set_filename(GTK_FILE_CHOOSER(file_chooser)
+                , archive_path))
+            gtk_file_chooser_set_current_name(
+                    GTK_FILE_CHOOSER(file_chooser), ARCFILE);
     }
     else { 
     /* this should actually never happen since we give default value in
      * creating the channel
      */
         g_warning("orage: archive file missing");
-        xfce_file_chooser_set_current_folder(XFCE_FILE_CHOOSER(file_chooser)
-            , rcfile);
+        gtk_file_chooser_set_current_folder(GTK_FILE_CHOOSER(file_chooser)
+                , rcfile);
     }
 	if (gtk_dialog_run(GTK_DIALOG(file_chooser)) == GTK_RESPONSE_ACCEPT) {
-		archive_path = xfce_file_chooser_get_filename(
-            XFCE_FILE_CHOOSER(file_chooser));
+		archive_path = gtk_file_chooser_get_filename(
+                GTK_FILE_CHOOSER(file_chooser));
         if (archive_path) {
             s = g_strdup(archive_path);
             gtk_entry_set_text(GTK_ENTRY(itf->archive_file_entry)
-                , (const gchar*) s);
+                    , (const gchar*) s);
             g_free(s);
         }
     }
@@ -300,36 +311,36 @@ static void cb_archive_file_open_button_clicked (GtkButton *button, gpointer use
 }
 
 static void cb_sound_application_open_button_clicked (GtkButton *button
-    , gpointer user_data)
+        , gpointer user_data)
 {
     Itf *itf = (Itf *) user_data;
     GtkWidget *file_chooser;
     gchar *s; /* to avoid timing problems when updating entry */
 
     /* Create file chooser */
-    file_chooser = xfce_file_chooser_new(_("Select a file..."),
-                                    GTK_WINDOW (itf->orage_dialog),
-                                    XFCE_FILE_CHOOSER_ACTION_OPEN,
-                                    GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-                                    GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT,
-                                        NULL);
+    file_chooser = gtk_file_chooser_dialog_new(_("Select a file..."),
+            GTK_WINDOW(itf->orage_dialog),
+            GTK_FILE_CHOOSER_ACTION_OPEN,
+            GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+            GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT,
+            NULL);
 
     /* Set sound application search path */
     if (sound_application == NULL
     ||  strlen(sound_application) == 0
     ||  sound_application[0] != '/'
-    || ! xfce_file_chooser_set_filename(XFCE_FILE_CHOOSER(file_chooser)
-        , sound_application))
-        xfce_file_chooser_set_current_folder(XFCE_FILE_CHOOSER(file_chooser)
-                    , "/usr/bin/");
+    || ! gtk_file_chooser_set_filename(GTK_FILE_CHOOSER(file_chooser)
+                , sound_application))
+        gtk_file_chooser_set_current_folder(GTK_FILE_CHOOSER(file_chooser)
+                , "/usr/bin/");
 
 	if (gtk_dialog_run(GTK_DIALOG(file_chooser)) == GTK_RESPONSE_ACCEPT) {
-		sound_application = xfce_file_chooser_get_filename(
-            XFCE_FILE_CHOOSER(file_chooser));
+		sound_application = gtk_file_chooser_get_filename(
+                GTK_FILE_CHOOSER(file_chooser));
         if (sound_application) {
             s = g_strdup(sound_application);
             gtk_entry_set_text(GTK_ENTRY(itf->sound_application_entry)
-                , (const gchar*) s);
+                    , (const gchar*) s);
             g_free(s);
         }
     }
@@ -462,7 +473,7 @@ static void cb_timezone_button_clicked (GtkButton *button, gpointer user_data)
     } while (result == 0) ;
     gtk_button_set_label(GTK_BUTTON(button), loc);
 
-    if (loc_int = g_object_get_data(G_OBJECT(button), "LOCATION_ENG"))
+    if ((loc_int = g_object_get_data(G_OBJECT(button), "LOCATION_ENG")))
                 g_free(loc_int);
     loc_int = g_strdup(loc_eng);
     g_object_set_data(G_OBJECT(button), "LOCATION_ENG", loc_int);
@@ -509,41 +520,37 @@ Itf *create_orage_dialog(McsPlugin * mcs_plugin)
     dialog->mode_radiobutton_group = NULL;
     dialog->visibility_radiobutton_group = NULL;
 
-    dialog->orage_dialog = gtk_dialog_new();
+    dialog->orage_dialog = xfce_titled_dialog_new();
     gtk_window_set_default_size(GTK_WINDOW(dialog->orage_dialog), 300, 350);
     gtk_window_set_title(GTK_WINDOW(dialog->orage_dialog), _("Orage Preferences"));
     gtk_window_set_position(GTK_WINDOW(dialog->orage_dialog), GTK_WIN_POS_CENTER);
     gtk_window_set_modal(GTK_WINDOW(dialog->orage_dialog), FALSE);
     gtk_window_set_resizable(GTK_WINDOW(dialog->orage_dialog), FALSE);
-    gtk_window_set_icon(GTK_WINDOW(dialog->orage_dialog), mcs_plugin->icon);
+    gtk_window_set_icon_name(GTK_WINDOW(dialog->orage_dialog), "xfcalendar");
 
     gtk_dialog_set_has_separator(GTK_DIALOG(dialog->orage_dialog), FALSE);
 
     dialog->dialog_vbox1 = GTK_DIALOG(dialog->orage_dialog)->vbox;
 
-    dialog->dialog_header = xfce_create_header(mcs_plugin->icon, _("Orage Preferences"));
-    gtk_box_pack_start(GTK_BOX(dialog->dialog_vbox1), dialog->dialog_header, FALSE, TRUE, 0);
-
     dialog->notebook = gtk_notebook_new ();
     gtk_container_add (GTK_CONTAINER (dialog->dialog_vbox1), dialog->notebook);
     gtk_container_set_border_width (GTK_CONTAINER (dialog->notebook), 5);
 
     /* Here begins display tab */
-    dialog->display_tab = xfce_framebox_new (NULL, FALSE);
-    dialog->display_tab_label = gtk_label_new (_("Display"));
-    gtk_notebook_append_page (GTK_NOTEBOOK (dialog->notebook)
-                              , dialog->display_tab
-                              , dialog->display_tab_label);
-
-    dialog->display_vbox = gtk_vbox_new (FALSE, 0);
-    xfce_framebox_add (XFCE_FRAMEBOX (dialog->display_tab)
-                       , dialog->display_vbox);
+    dialog->display_vbox = gtk_vbox_new(FALSE, 0);
+    dialog->display_tab = 
+        xfce_create_framebox_with_content(NULL, dialog->display_vbox);
+    dialog->display_tab_label = gtk_label_new(_("Display"));
+    gtk_notebook_append_page(GTK_NOTEBOOK(dialog->notebook)
+          , dialog->display_tab, dialog->display_tab_label);
 
     /* Display calendar borders or not */
-    dialog->mode_frame = xfce_framebox_new (_("Calendar borders"), TRUE);
-    gtk_box_pack_start(GTK_BOX(dialog->display_vbox), dialog->mode_frame, TRUE, TRUE, 0);
     dialog->mode_hbox = gtk_hbox_new(TRUE, 0);
-    xfce_framebox_add(XFCE_FRAMEBOX(dialog->mode_frame), dialog->mode_hbox);
+    dialog->mode_frame = 
+        xfce_create_framebox_with_content(_("Calendar borders")
+                , dialog->mode_hbox);
+    gtk_box_pack_start(GTK_BOX(dialog->display_vbox), dialog->mode_frame
+            , TRUE, TRUE, 0);
 
     dialog->normal_mode_radiobutton = gtk_radio_button_new_with_mnemonic(NULL, _("Displayed"));
     gtk_box_pack_start(GTK_BOX(dialog->mode_hbox), dialog->normal_mode_radiobutton, FALSE, FALSE, 0);
@@ -558,11 +565,12 @@ Itf *create_orage_dialog(McsPlugin * mcs_plugin)
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(dialog->compact_mode_radiobutton), !normalmode);
     
     /* Show in... taskbar pager systray */
-    dialog->show_frame = xfce_framebox_new(_("Calendar window"), TRUE);
-    gtk_box_pack_start(GTK_BOX(dialog->display_vbox), dialog->show_frame, TRUE, TRUE, 5);
-     
     dialog->show_vbox = gtk_vbox_new(TRUE, 0);
-    xfce_framebox_add(XFCE_FRAMEBOX(dialog->show_frame), dialog->show_vbox);
+    dialog->show_frame = 
+        xfce_create_framebox_with_content(_("Calendar window")
+                , dialog->show_vbox);
+    gtk_box_pack_start(GTK_BOX(dialog->display_vbox), dialog->show_frame
+            , TRUE, TRUE, 5);
 
     dialog->show_taskbar_checkbutton = gtk_check_button_new_with_mnemonic(_("Show in taskbar"));
     gtk_box_pack_start(GTK_BOX(dialog->show_vbox), dialog->show_taskbar_checkbutton, FALSE, FALSE, 0);
@@ -576,11 +584,13 @@ Itf *create_orage_dialog(McsPlugin * mcs_plugin)
     gtk_box_pack_start(GTK_BOX(dialog->show_vbox), dialog->show_systray_checkbutton, FALSE, FALSE, 0);
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(dialog->show_systray_checkbutton), showsystray);
 
-    /* */
-    dialog->visibility_frame = xfce_framebox_new(_("Calendar start"), TRUE);
-    gtk_box_pack_start(GTK_BOX(dialog->display_vbox), dialog->visibility_frame, TRUE, TRUE, 5);
+    /* how to show when started (show/hide/minimize) */
     dialog->visibility_hbox = gtk_hbox_new(TRUE, 0);
-    xfce_framebox_add(XFCE_FRAMEBOX(dialog->visibility_frame), dialog->visibility_hbox);
+    dialog->visibility_frame = 
+        xfce_create_framebox_with_content(_("Calendar start")
+                , dialog->visibility_hbox);
+    gtk_box_pack_start(GTK_BOX(dialog->display_vbox), dialog->visibility_frame
+            , TRUE, TRUE, 5);
 
     dialog->visibility_show_radiobutton = gtk_radio_button_new_with_mnemonic(NULL, _("Show"));
     gtk_box_pack_start(GTK_BOX(dialog->visibility_hbox), dialog->visibility_show_radiobutton, FALSE, FALSE, 0);
@@ -601,25 +611,24 @@ Itf *create_orage_dialog(McsPlugin * mcs_plugin)
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(dialog->visibility_minimized_radiobutton), ministart);
 
     /* Here begins archives tab */
-    dialog->archives_tab = xfce_framebox_new (NULL, FALSE);
-    dialog->archives_tab_label = gtk_label_new (_("Archives"));
-    gtk_notebook_append_page (GTK_NOTEBOOK (dialog->notebook)
-                              , dialog->archives_tab
-                              , dialog->archives_tab_label);
+    dialog->archive_vbox = gtk_vbox_new(FALSE, 0);
+    dialog->archives_tab = 
+        xfce_create_framebox_with_content(NULL, dialog->archive_vbox);
+    dialog->archives_tab_label = gtk_label_new(_("Archives"));
+    gtk_notebook_append_page(GTK_NOTEBOOK(dialog->notebook)
+          , dialog->archives_tab, dialog->archives_tab_label);
 
-    dialog->archive_vbox = gtk_vbox_new (FALSE, 0);
-    xfce_framebox_add (XFCE_FRAMEBOX (dialog->archives_tab)
-                       , dialog->archive_vbox);
     /* Archive file and periodicity */
-    dialog->archive_file_frame = xfce_framebox_new (_("Archive file"), TRUE);
-    gtk_box_pack_start (GTK_BOX (dialog->archive_vbox), dialog->archive_file_frame, TRUE, TRUE, 5);
-
     dialog->archive_file_table = gtk_table_new (1, 2, FALSE);
-    gtk_container_set_border_width (GTK_CONTAINER (dialog->archive_file_table), 10);
-    gtk_table_set_row_spacings (GTK_TABLE (dialog->archive_file_table), 6);
-    gtk_table_set_col_spacings (GTK_TABLE (dialog->archive_file_table), 6);
-    xfce_framebox_add (XFCE_FRAMEBOX (dialog->archive_file_frame)
-                       , dialog->archive_file_table);
+    gtk_container_set_border_width(GTK_CONTAINER(dialog->archive_file_table)
+            , 10);
+    gtk_table_set_row_spacings(GTK_TABLE(dialog->archive_file_table), 6);
+    gtk_table_set_col_spacings(GTK_TABLE(dialog->archive_file_table), 6);
+    dialog->archive_file_frame = 
+        xfce_create_framebox_with_content(_("Archive file")
+                , dialog->archive_file_table);
+    gtk_box_pack_start(GTK_BOX(dialog->archive_vbox)
+            , dialog->archive_file_frame, TRUE, TRUE, 5);
 
     dialog->archive_file_entry = gtk_entry_new ();
     gtk_table_attach (GTK_TABLE (dialog->archive_file_table), dialog->archive_file_entry, 0, 1, 0, 1,
@@ -632,18 +641,16 @@ Itf *create_orage_dialog(McsPlugin * mcs_plugin)
                         (GtkAttachOptions) (GTK_FILL),
                         (GtkAttachOptions) (0), 0, 0);
 
-    dialog->archive_threshold_frame = 
-        xfce_framebox_new(_("Archive threshold"), TRUE);
-    gtk_box_pack_start(GTK_BOX (dialog->archive_vbox),
-        dialog->archive_threshold_frame, TRUE, TRUE, 5);
-
-    dialog->archive_threshold_table = gtk_table_new (1, 1, FALSE);
+    dialog->archive_threshold_table = gtk_table_new(1, 1, FALSE);
     gtk_container_set_border_width(
-        GTK_CONTAINER(dialog->archive_threshold_table), 10);
+            GTK_CONTAINER(dialog->archive_threshold_table), 10);
     gtk_table_set_row_spacings(GTK_TABLE(dialog->archive_threshold_table), 6);
     gtk_table_set_col_spacings(GTK_TABLE(dialog->archive_threshold_table), 6);
-    xfce_framebox_add (XFCE_FRAMEBOX (dialog->archive_threshold_frame)
-                       , dialog->archive_threshold_table);
+    dialog->archive_threshold_frame = 
+        xfce_create_framebox_with_content(_("Archive threshold")
+                , dialog->archive_threshold_table);
+    gtk_box_pack_start(GTK_BOX(dialog->archive_vbox)
+            , dialog->archive_threshold_frame, TRUE, TRUE, 5);
 
     dialog->archive_threshold_combobox = gtk_combo_box_new_text ();
     gtk_combo_box_append_text(
@@ -678,26 +685,24 @@ Itf *create_orage_dialog(McsPlugin * mcs_plugin)
                         (GtkAttachOptions) (0), 0, 0);
 
     /* Here begins the sound tab */
-    dialog->sound_tab = xfce_framebox_new (NULL, FALSE);
-    dialog->sound_tab_label = gtk_label_new (_("Sound"));
-    gtk_notebook_append_page (GTK_NOTEBOOK (dialog->notebook)
-                              , dialog->sound_tab
-                              , dialog->sound_tab_label);
+    dialog->sound_vbox = gtk_vbox_new(FALSE, 0);
+    dialog->sound_tab = 
+        xfce_create_framebox_with_content(NULL, dialog->sound_vbox);
+    dialog->sound_tab_label = gtk_label_new(_("Sound"));
+    gtk_notebook_append_page(GTK_NOTEBOOK(dialog->notebook)
+          , dialog->sound_tab, dialog->sound_tab_label);
 
     /* Choose a sound application for reminders */
-    dialog->sound_vbox = gtk_vbox_new (FALSE, 0);
-    xfce_framebox_add (XFCE_FRAMEBOX (dialog->sound_tab)
-                       , dialog->sound_vbox);
-
-    dialog->sound_application_frame = xfce_framebox_new(_("Application"), TRUE);
-    gtk_box_pack_start(GTK_BOX(dialog->sound_vbox), dialog->sound_application_frame, TRUE, TRUE, 5);
-
     dialog->sound_application_table = gtk_table_new(1, 2, FALSE);
-    gtk_container_set_border_width(GTK_CONTAINER(dialog->sound_application_table), 10);
+    gtk_container_set_border_width(
+            GTK_CONTAINER(dialog->sound_application_table), 10);
     gtk_table_set_row_spacings(GTK_TABLE(dialog->sound_application_table), 6);
     gtk_table_set_col_spacings(GTK_TABLE(dialog->sound_application_table), 6);
-    xfce_framebox_add(XFCE_FRAMEBOX(dialog->sound_application_frame)
-                       , dialog->sound_application_table);
+    dialog->sound_application_frame = 
+        xfce_create_framebox_with_content(_("Application")
+                , dialog->sound_application_table);
+    gtk_box_pack_start(GTK_BOX(dialog->sound_vbox)
+            , dialog->sound_application_frame, TRUE, TRUE, 5);
 
     dialog->sound_application_entry = gtk_entry_new();
     gtk_table_attach(GTK_TABLE(dialog->sound_application_table)
@@ -711,26 +716,25 @@ Itf *create_orage_dialog(McsPlugin * mcs_plugin)
                         (GtkAttachOptions) (0), 0, 0);
 
     /* Here begins the timezone tab */
-    dialog->timezone_tab = xfce_framebox_new (NULL, FALSE);
-    dialog->timezone_tab_label = gtk_label_new (_("Timezone"));
-    gtk_notebook_append_page (GTK_NOTEBOOK (dialog->notebook)
-                              , dialog->timezone_tab
-                              , dialog->timezone_tab_label);
+    dialog->timezone_vbox = gtk_vbox_new(FALSE, 0);
+    dialog->timezone_tab = 
+        xfce_create_framebox_with_content(NULL, dialog->timezone_vbox);
+    dialog->timezone_tab_label = gtk_label_new(_("Timezone"));
+    gtk_notebook_append_page(GTK_NOTEBOOK(dialog->notebook)
+          , dialog->timezone_tab, dialog->timezone_tab_label);
 
     /* Choose a timezone to be used in appointments */
-    dialog->timezone_vbox = gtk_vbox_new (FALSE, 0);
-    xfce_framebox_add (XFCE_FRAMEBOX (dialog->timezone_tab)
-                       , dialog->timezone_vbox);
+    dialog->timezone_table = gtk_table_new(1, 1, FALSE);
+    gtk_container_set_border_width(
+            GTK_CONTAINER(dialog->timezone_table), 10);
+    gtk_table_set_row_spacings(GTK_TABLE(dialog->timezone_table), 6);
+    gtk_table_set_col_spacings(GTK_TABLE(dialog->timezone_table), 6);
+    dialog->timezone_frame = 
+        xfce_create_framebox_with_content(_("Timezone")
+                , dialog->timezone_table);
+    gtk_box_pack_start(GTK_BOX(dialog->timezone_vbox)
+            , dialog->timezone_frame, TRUE, TRUE, 5);
 
-    dialog->timezone_frame = xfce_framebox_new (_("Timezone"), TRUE);
-    gtk_box_pack_start (GTK_BOX (dialog->timezone_vbox), dialog->timezone_frame, TRUE, TRUE, 5);
-
-    dialog->timezone_table = gtk_table_new (1, 1, FALSE);
-    gtk_container_set_border_width (GTK_CONTAINER (dialog->timezone_table), 10);
-    gtk_table_set_row_spacings (GTK_TABLE (dialog->timezone_table), 6);
-    gtk_table_set_col_spacings (GTK_TABLE (dialog->timezone_table), 6);
-    xfce_framebox_add (XFCE_FRAMEBOX (dialog->timezone_frame)
-                       , dialog->timezone_table);
     dialog->timezone_button = gtk_button_new();
     if (local_timezone) {
         gtk_button_set_label(GTK_BUTTON(dialog->timezone_button), _(local_timezone));
@@ -785,9 +789,12 @@ McsPluginInitResult mcs_plugin_init(McsPlugin * mcs_plugin)
 
     create_channel(mcs_plugin);
     mcs_plugin->plugin_name = g_strdup(PLUGIN_NAME);
-    mcs_plugin->caption = g_strdup(_("Orage"));
+    /* the button label in the xfce-mcs-manager dialog */
+    mcs_plugin->caption = g_strdup(Q_("Button Label|Orage"));
     mcs_plugin->run_dialog = run_dialog;
     mcs_plugin->icon = xfce_themed_icon_load("xfcalendar", 48);
+    if (G_LIKELY (mcs_plugin->icon != NULL))
+      g_object_set_data_full(G_OBJECT(mcs_plugin->icon), "mcs-plugin-icon-name", g_strdup("xfcalendar"), g_free);
     mcs_manager_notify(mcs_plugin->manager, CHANNEL);
 
     return (MCS_PLUGIN_INIT_OK);
