@@ -1,4 +1,4 @@
-/*      $Id: hints.h 20530 2006-03-24 14:46:35Z olivier $
+/*      $Id: hints.h 22243 2006-07-02 16:23:01Z olivier $
  
         This program is free software; you can redistribute it and/or modify
         it under the terms of the GNU General Public License as published by
@@ -111,6 +111,11 @@
 
 #define NET_WM_OPAQUE                           0xffffffff
 
+/* Convenient macro */
+#define HINTS_ACCEPT_INPUT(wmhints)     (!(wmhints) ||                                                              \
+                                         ((wmhints) && !(wmhints->flags & InputHint)) ||                            \
+                                         ((wmhints) && (wmhints->flags & InputHint) && (wmhints->input)))
+
 typedef struct
 {
     unsigned long orientation;
@@ -156,21 +161,23 @@ gboolean getCardinalList (DisplayInfo *, Window, int, unsigned long **, int *);
 void setNetWorkarea (DisplayInfo *, Window, int, int, int, int *);
 void setNetFrameExtents (DisplayInfo *, Window, int, int, int, int);
 void initNetDesktopInfo (DisplayInfo *, Window, int, int, int);
-void setUTF8StringHint (DisplayInfo *, Window, int, const char *);
+void setUTF8StringHint (DisplayInfo *, Window, int, const gchar *);
 void getTransientFor (DisplayInfo *, Window, Window, Window *);
-void getWindowName (DisplayInfo *, Window, char **);
-gboolean getUTF8String (DisplayInfo *, Window, int, char **, int *);
-gboolean getUTF8StringList (DisplayInfo *, Window, int, char ***, int *);
-void getWindowName (DisplayInfo *, Window, char **);
-gboolean getWindowRole (DisplayInfo *, Window, char **);
+gboolean getWindowName (DisplayInfo *, Window, gchar **);
+gboolean getUTF8String (DisplayInfo *, Window, int, gchar **, int *);
+gboolean getUTF8StringList (DisplayInfo *, Window, int, gchar ***, int *);
+gboolean getClientMachine (DisplayInfo *, Window, gchar **);
+gboolean getClientMachine (DisplayInfo *, Window, gchar **);
+gboolean getWindowRole (DisplayInfo *, Window, gchar **);
 Window getClientLeader (DisplayInfo *, Window);
 gboolean getNetWMUserTime (DisplayInfo *, Window, Time *);
-gboolean getClientID (DisplayInfo *, Window, char **);
+gboolean getClientID (DisplayInfo *, Window, gchar **);
 gboolean getWindowCommand (DisplayInfo *, Window, char ***, int *);
 gboolean getKDEIcon (DisplayInfo *, Window, Pixmap *, Pixmap *);
 gboolean getRGBIconData (DisplayInfo *, Window, unsigned long **, unsigned long *);
 gboolean getOpacity (DisplayInfo *, Window, guint *);
-gboolean setCompositingManagerOwner (DisplayInfo *, Window , Window);
+gboolean getOpacityLock (DisplayInfo *, Window);
+gboolean setAtomManagerOwner (DisplayInfo *, int, Window , Window);
 
 #ifdef ENABLE_KDE_SYSTRAY_PROXY
 gboolean checkKdeSystrayWindow(DisplayInfo *, Window);
