@@ -1,4 +1,4 @@
-/*      $Id: main.c 20674 2006-04-01 20:38:05Z olivier $
+/*      $Id: main.c 22245 2006-07-02 19:35:59Z olivier $
  
         This program is free software; you can redistribute it and/or modify
         it under the terms of the GNU General Public License as published by
@@ -46,6 +46,7 @@
 #include "display.h"
 #include "screen.h"
 #include "events.h"
+#include "event_filter.h"
 #include "frame.h"
 #include "settings.h"
 #include "client.h"
@@ -80,28 +81,7 @@
 static char revision[]="@(#)$ " PACKAGE " version " VERSION " revision " REVISION " $";
 #endif
 
-static DisplayInfo *display_info = NULL;
-gboolean xfwm4_quit           = FALSE;
-gboolean xfwm4_reload         = FALSE;
-
-static void
-compute_delta_t (struct timeval *start, struct timeval *stop, struct timeval *delta)
-{
-    delta->tv_sec = stop->tv_sec - start->tv_sec;
-    delta->tv_usec = stop->tv_usec - start->tv_usec;
-
-    if (delta->tv_usec >= 1000000)
-    {
-        delta->tv_sec += 1;
-        delta->tv_usec -= 1000000;
-    }
-
-    if (delta->tv_usec < 0)
-    {
-        delta->tv_sec -= 1;
-        delta->tv_usec += 1000000;
-    }
-}
+static DisplayInfo *display_info;
 
 static void
 cleanUp (void)
@@ -112,7 +92,7 @@ cleanUp (void)
     
     TRACE ("entering cleanUp");
 
-    xfce_close_event_filter (display_info->xfilter);
+    eventFilterClose (display_info->xfilter);
     for (screens = display_info->screens; screens; screens = g_slist_next (screens))
     {
         ScreenInfo *screen_info_n = (ScreenInfo *) screens->data;
@@ -127,64 +107,6 @@ cleanUp (void)
     display_info = NULL;
 }
 
-static char *
-build_session_filename(SessionClient *client_session)
-{
-    gchar *filename, *path, *file;
-    GError *error = NULL;
-
-    path = xfce_resource_save_location (XFCE_RESOURCE_CACHE, "sessions", FALSE);
-    
-    if (!xfce_mkdirhier(path, 0700, &error)) 
-    {
-        g_warning("Unable to create session dir %s: %s", path, error->message);
-        g_error_free (error);
-        g_free (path);
-        return NULL;
-    }
-
-    file = g_strdup_printf("xfwm4-%s", client_session->given_client_id);
-    filename = g_build_filename (path, file, NULL);
-    g_free (file);
-    g_free (path);
-    
-    return filename;
-}
-
-static void
-load_saved_session (SessionClient *client_session)
-{
-    gchar *filename;
-    
-    filename = build_session_filename(client_session);
-    if (filename)
-    {
-        sessionLoadWindowStates (filename);
-        g_free (filename);
-    }
-}
-
-static void
-save_phase_2 (gpointer data)
-{
-    SessionClient *client_session = (SessionClient *) data;
-    gchar *filename;
-
-    filename = build_session_filename(client_session);
-    if (filename)
-    {
-        sessionSaveWindowStates (display_info, filename);
-        g_free (filename);
-    }
-}
-
-static void
-session_die (gpointer client_data)
-{
-    gtk_main_quit ();
-    xfwm4_quit = TRUE;
-}
-
 static void
 handleSignal (int sig)
 {
@@ -195,11 +117,11 @@ handleSignal (int sig)
         case SIGINT:
         case SIGTERM:
             gtk_main_quit ();
-            xfwm4_quit = TRUE;
+            display_info->quit = TRUE;
             break;
         case SIGHUP:
         case SIGUSR1:
-            xfwm4_reload = TRUE;
+            display_info->reload = TRUE;
             break;
         case SIGSEGV:
             cleanUp ();
@@ -214,7 +136,7 @@ static void
 ensure_basedir_spec (void)
 {
     char *new, *old, path[PATH_MAX];
-    GError *error = NULL;
+    GError *error;
     GDir *gdir;
     const char *name;
 
@@ -230,6 +152,7 @@ ensure_basedir_spec (void)
         return;
     }
 
+    error = NULL;
     if (!xfce_mkdirhier(new, 0700, &error)) 
     {
         g_warning("Unable to create config dir %s: %s", new, error->message);
@@ -258,7 +181,7 @@ ensure_basedir_spec (void)
         
         if (w && r)
         {
-            char c;
+            int c;
             
             while ((c = getc (r)) != EOF)
             {
@@ -282,7 +205,6 @@ ensure_basedir_spec (void)
     /* copy saved session data */
     
     new = xfce_resource_save_location (XFCE_RESOURCE_CACHE, "sessions", FALSE);
-
     if (!xfce_mkdirhier(new, 0700, &error)) 
     {
         g_warning("Unable to create session dir %s: %s", new, error->message);
@@ -308,7 +230,7 @@ ensure_basedir_spec (void)
 
             if (w && r)
             {
-                char c;
+                int c;
                 
                 while ((c = getc (r)) != EOF)
                     putc (c, w);
@@ -377,6 +299,12 @@ print_version (void)
     g_print ("Yes\n");
 #else
     g_print ("No\n");
+#endif    
+    g_print ("\t- KDE systray proxy (deprecated):               ");
+#ifdef ENABLE_KDE_SYSTRAY_PROXY
+    g_print ("Yes\n");
+#else
+    g_print ("No\n");
 #endif    
     exit (0);
 }
@@ -386,24 +314,33 @@ static gint
 get_default_compositor (DisplayInfo *display_info)
 {
     /* 
-       Check if the XServer is black listed.
+     * Don't even check for the render speed if there is no compositor.
+     */
+    if (!display_info->enable_compositor)
+    {
+        return 0;
+    }
+
+    /* 
+     * Check if the XServer is black listed.
      */
     if (!compositorTestServer (display_info))
     {
         g_warning ("The XServer currently in use on this system is not suitable for the compositor");
         return 0;
     }
-    
+
+#if 0
     /* 
-       Test if the XRender implementation is fast enough for the
-       compositor.
+     * Test if the XRender implementation is fast enough for the
+     * compositor.
      */
-    if (!myDisplayTestXrender (display_info, 0.01))
+    if (!myDisplayTestXrender (display_info, 0.025))
     {
         g_warning ("The XRender implementation currently in use on this system is too slow for the compositor");
         return 0;
     }
-
+#endif
     return 2;
 }
 #endif /* HAVE_COMPOSITOR */
@@ -413,23 +350,24 @@ static gint
 parse_compositor (const gchar *s)
 {
     gchar *rvalue;
-    gboolean retval = 2;
+    gint retval;
 
+    retval = 2;
     rvalue = strrchr (s, '=');
     if (rvalue)
     {
         rvalue++;
         if (!strcmp (rvalue, "off"))
         {
-            retval=0;
+            retval = 0;
         }
         else if (!strcmp (rvalue, "auto"))
         {
-            retval=1;
+            retval = 1;
         }
         else if (!strcmp (rvalue, "on"))
         {
-            retval=2;
+            retval = 2;
         }
         else
         {
@@ -446,7 +384,6 @@ initialize (int argc, char **argv, gint compositor_mode)
 {
     struct sigaction act;
     long ws;
-    SessionClient *client_session;
     gint i, nscreens;
     
     TRACE ("entering initialize");
@@ -476,6 +413,7 @@ initialize (int argc, char **argv, gint compositor_mode)
     {
         display_info->enable_compositor = FALSE;
     }
+    compositorSetCompositeMode (display_info, (compositor_mode == 2));
 #else /* HAVE_COMPOSITOR */
     display_info->enable_compositor = FALSE;
 #endif /* HAVE_COMPOSITOR */
@@ -493,7 +431,7 @@ initialize (int argc, char **argv, gint compositor_mode)
     nscreens = gdk_display_get_n_screens(display_info->gdisplay);
     for(i = 0; i < nscreens; i++) 
     {
-        ScreenInfo *screen_info = NULL;
+        ScreenInfo *screen_info;
         GdkScreen *gscr;
         
         gscr = gdk_display_get_screen(display_info->gdisplay, i);
@@ -511,9 +449,22 @@ initialize (int argc, char **argv, gint compositor_mode)
         
         if (compositor_mode)
         {
-            if (compositorManageScreen (screen_info, (compositor_mode == 2)))
+            gboolean xfwm4_compositor;
+            
+            xfwm4_compositor = (compositor_mode > 1);
+            if (screen_info->params->use_compositing)
             {
-                setCompositingManagerOwner (display_info,  screen_info->xroot, screen_info->xfwm4_win);
+                xfwm4_compositor = compositorManageScreen (screen_info);
+            }
+            if (xfwm4_compositor)
+            {
+                /* 
+                   Acquire selection on XFWM4_COMPOSITING_MANAGER to advertise our own
+                   compositing manager (used by WM tweaks to determine whether or not
+                   show the "compositor" tab.
+                 */
+                setAtomManagerOwner (display_info, XFWM4_COMPOSITING_MANAGER, 
+                                     screen_info->xroot, screen_info->xfwm4_win);
             }
         }
 
@@ -529,8 +480,8 @@ initialize (int argc, char **argv, gint compositor_mode)
         setUTF8StringHint (display_info, screen_info->xfwm4_win, NET_WM_NAME, "Xfwm4");
         setNetSupportedHint (display_info, screen_info->xroot, screen_info->xfwm4_win);
         initNetDesktopInfo (display_info, screen_info->xroot, screen_info->current_ws,
-                                   gdk_screen_get_width (screen_info->gscr), 
-                                   gdk_screen_get_height (screen_info->gscr));
+                                   screen_info->width, 
+                                   screen_info->height);
         workspaceUpdateArea (screen_info);
         XSetInputFocus (display_info->dpy, screen_info->xfwm4_win, RevertToPointerRoot, CurrentTime);
 
@@ -546,33 +497,24 @@ initialize (int argc, char **argv, gint compositor_mode)
     {
         return -1;
     }
-    display_info->xfilter = xfce_init_event_filter ((gpointer) display_info);
-    xfce_push_event_filter (display_info->xfilter, xfwm4_event_filter, (gpointer) display_info);
+    display_info->xfilter = eventFilterInit ((gpointer) display_info);
+    eventFilterPush (display_info->xfilter, xfwm4_event_filter, (gpointer) display_info);
 
-    client_session = client_session_new (argc, argv, (gpointer) display_info, 
-                                         SESSION_RESTART_IF_RUNNING, 20);
-    client_session->data = (gpointer) client_session;
-    client_session->save_phase_2 = save_phase_2;
-    client_session->die = session_die;
-
-    if (session_init (client_session))
-    {
-        load_saved_session (client_session);
-        return 1;
-    }
-
-    return 0;
+    return sessionStart (argc, argv, display_info);
 }
 
 int
 main (int argc, char **argv)
 {
-    int i;
-    gboolean daemon_mode = FALSE;
-    gint compositor = -1;
+    gboolean daemon_mode;
+    gint compositor;
     int status;
+    int i;
 
     DBG ("xfwm4 starting");
+
+    daemon_mode = FALSE;
+    compositor = -1;
     for (i = 1; i < argc; i++)
     {
         if (!strcmp (argv[i], "--daemon"))
