@@ -1,4 +1,4 @@
-/*      $Id: netwm.c 20324 2006-03-10 23:35:23Z olivier $
+/*      $Id: netwm.c 22198 2006-06-25 09:06:45Z olivier $
  
         This program is free software; you can redistribute it and/or modify
         it under the terms of the GNU General Public License as published by
@@ -30,7 +30,6 @@
 #include <gdk/gdkx.h>
 #include <gtk/gtk.h>
 #include <libxfce4util/libxfce4util.h> 
-#include <libxfcegui4/libxfcegui4.h>
 
 #include "display.h"
 #include "screen.h"
@@ -46,8 +45,8 @@
 void
 clientSetNetState (Client * c)
 {
-    ScreenInfo *screen_info = NULL;
-    DisplayInfo *display_info = NULL;
+    ScreenInfo *screen_info;
+    DisplayInfo *display_info;
     Atom data[16];
     int i;
 
@@ -138,10 +137,10 @@ clientSetNetState (Client * c)
 void
 clientGetNetState (Client * c)
 {
-    ScreenInfo *screen_info = NULL;
-    DisplayInfo *display_info = NULL;
-    int n_atoms = 0;
-    Atom *atoms = NULL;
+    ScreenInfo *screen_info;
+    DisplayInfo *display_info;
+    int n_atoms;
+    Atom *atoms;
 
     g_return_if_fail (c != NULL);
     TRACE ("entering clientGetNetState");
@@ -149,6 +148,8 @@ clientGetNetState (Client * c)
 
     screen_info = c->screen_info;
     display_info = screen_info->display_info;
+    atoms = NULL;
+    n_atoms = 0;
 
     if (FLAG_TEST (c->xfwm_flags, XFWM_FLAG_SESSION_MANAGED))
     {
@@ -276,9 +277,9 @@ clientGetNetState (Client * c)
 void
 clientUpdateNetState (Client * c, XClientMessageEvent * ev)
 {
-    ScreenInfo *screen_info = NULL;
-    DisplayInfo *display_info = NULL;
-    unsigned long action;
+    ScreenInfo *screen_info;
+    DisplayInfo *display_info;
+    unsigned long action, mode;
     Atom first;
     Atom second;
 
@@ -292,6 +293,7 @@ clientUpdateNetState (Client * c, XClientMessageEvent * ev)
     action = ((XEvent *) ev)->xclient.data.l[0];
     first  = ((XEvent *) ev)->xclient.data.l[1];
     second = ((XEvent *) ev)->xclient.data.l[2];
+    mode = 0;
 
     if ((first  == display_info->atoms[NET_WM_STATE_SHADED]) || 
         (second == display_info->atoms[NET_WM_STATE_SHADED]))
@@ -357,7 +359,7 @@ clientUpdateNetState (Client * c, XClientMessageEvent * ev)
         {
             if ((action == NET_WM_STATE_ADD) && !FLAG_TEST (c->flags, CLIENT_FLAG_MAXIMIZED))
             {
-                unsigned long mode = 0;
+                mode = 0;
                 if ((first  == display_info->atoms[NET_WM_STATE_MAXIMIZED_HORZ]) ||
                     (second == display_info->atoms[NET_WM_STATE_MAXIMIZED_HORZ]))
                 {
@@ -372,7 +374,7 @@ clientUpdateNetState (Client * c, XClientMessageEvent * ev)
             }
             else if ((action == NET_WM_STATE_REMOVE) && FLAG_TEST (c->flags, CLIENT_FLAG_MAXIMIZED))
             {
-                unsigned long mode = 0;
+                mode = 0;
                 if ((first  == display_info->atoms[NET_WM_STATE_MAXIMIZED_HORZ]) ||
                     (second == display_info->atoms[NET_WM_STATE_MAXIMIZED_HORZ]))
                 {
@@ -387,7 +389,7 @@ clientUpdateNetState (Client * c, XClientMessageEvent * ev)
             }
             else if (action == NET_WM_STATE_TOGGLE)
             {
-                unsigned long mode = 0;
+                mode = 0;
                 if ((first  == display_info->atoms[NET_WM_STATE_MAXIMIZED_HORZ]) ||
                     (second == display_info->atoms[NET_WM_STATE_MAXIMIZED_HORZ]))
                 {
@@ -606,10 +608,10 @@ clientUpdateFullscreenState (Client * c)
 void
 clientGetNetWmType (Client * c)
 {
-    ScreenInfo *screen_info = NULL;
-    DisplayInfo *display_info = NULL;
-    int n_atoms = 0;
-    Atom *atoms = NULL;
+    ScreenInfo *screen_info;
+    DisplayInfo *display_info;
+    int n_atoms;
+    Atom *atoms;
     int i;
 
     g_return_if_fail (c != NULL);
@@ -618,7 +620,6 @@ clientGetNetWmType (Client * c)
 
     screen_info = c->screen_info;
     display_info = screen_info->display_info;
-
     n_atoms = 0;
     atoms = NULL;
 
@@ -670,10 +671,10 @@ clientGetNetWmType (Client * c)
 void
 clientGetInitialNetWmDesktop (Client * c)
 {
-    ScreenInfo *screen_info = NULL;
-    DisplayInfo *display_info = NULL;
-    Client *c2 = NULL;
-    long val = 0;
+    ScreenInfo *screen_info;
+    DisplayInfo *display_info;
+    Client *c2;
+    long val;
 
     g_return_if_fail (c != NULL);
     TRACE ("entering clientGetInitialNetWmDesktop");
@@ -681,6 +682,7 @@ clientGetInitialNetWmDesktop (Client * c)
 
     screen_info = c->screen_info;
     display_info = screen_info->display_info;
+    val = 0;
 
     /* This is to make sure that transient are shown with their "ancestor" window */
     c2 = clientGetTransient (c);
@@ -781,9 +783,9 @@ clientSetNetClientList (ScreenInfo * screen_info, Atom a, GList * list)
 void
 clientGetNetStruts (Client * c)
 {
-    ScreenInfo *screen_info = NULL;
-    DisplayInfo *display_info = NULL;
-    gulong *struts = NULL;
+    ScreenInfo *screen_info;
+    DisplayInfo *display_info;
+    gulong *struts;
     int nitems;
     int i;
 
@@ -792,6 +794,7 @@ clientGetNetStruts (Client * c)
 
     screen_info = c->screen_info;
     display_info = screen_info->display_info;
+    struts = NULL;
 
     for (i = 0; i < 12; i++)
     {
@@ -844,10 +847,10 @@ clientGetNetStruts (Client * c)
         /* Fill(in values as for partial struts */
         c->struts[TOP_START_X] = c->struts[BOTTOM_START_X] = 0;
         c->struts[TOP_END_X] = c->struts[BOTTOM_END_X] = 
-            gdk_screen_get_width (c->screen_info->gscr);
+            c->screen_info->width;
         c->struts[LEFT_START_Y] = c->struts[RIGHT_START_Y] = 0;
         c->struts[LEFT_END_Y] = c->struts[RIGHT_END_Y] = 
-            gdk_screen_get_height (c->screen_info->gscr);
+            c->screen_info->height;
         
         XFree (struts);
         workspaceUpdateArea (c->screen_info);
@@ -857,16 +860,17 @@ clientGetNetStruts (Client * c)
 void
 clientSetNetActions (Client * c)
 {
-    ScreenInfo *screen_info = NULL;
-    DisplayInfo *display_info = NULL;
+    ScreenInfo *screen_info;
+    DisplayInfo *display_info;
     Atom atoms[6];
-    int i = 0;
+    int i;
 
     g_return_if_fail (c != NULL);
     TRACE ("entering clientSetNetActions");
 
     screen_info = c->screen_info;
     display_info = screen_info->display_info;
+    i = 0;
 
     atoms[i++] = display_info->atoms[NET_WM_ACTION_CLOSE];
     if (CLIENT_CAN_MAXIMIZE_WINDOW (c))
@@ -890,8 +894,8 @@ clientSetNetActions (Client * c)
 void
 clientWindowType (Client * c)
 {
-    ScreenInfo *screen_info = NULL;
-    DisplayInfo *display_info = NULL;
+    ScreenInfo *screen_info;
+    DisplayInfo *display_info;
     netWindowType old_type;
 
     g_return_if_fail (c != NULL);
