@@ -1,4 +1,4 @@
-/*      $Id: stacking.c,v 1.24 2004/10/27 16:56:54 olivier Exp $
+/*      $Id: stacking.c 21716 2006-05-18 19:11:40Z olivier $
  
         This program is free software; you can redistribute it and/or modify
         it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
         along with this program; if not, write to the Free Software
         Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  
-        xfwm4    - (c) 2002-2004 Olivier Fourdan
+        xfwm4    - (c) 2002-2006 Olivier Fourdan
  
  */
 
@@ -39,11 +39,12 @@ clientApplyStackList (ScreenInfo *screen_info)
 {
     Window *xwinstack;
     guint nwindows;
-    gint i = 0;
+    gint i;
 
     DBG ("applying stack list");
     nwindows = g_list_length (screen_info->windows_stack);
 
+    i = 0;
     xwinstack = g_new (Window, nwindows + 4);
     xwinstack[i++] = MYWINDOW_XWINDOW (screen_info->sidewalk[0]);
     xwinstack[i++] = MYWINDOW_XWINDOW (screen_info->sidewalk[1]);
@@ -52,7 +53,7 @@ clientApplyStackList (ScreenInfo *screen_info)
 
     if (nwindows)
     {
-        GList *index = NULL;
+        GList *index;
         Client *c = NULL;
 
         for (index = g_list_last(screen_info->windows_stack); index; index = g_list_previous (index))
@@ -71,14 +72,15 @@ clientApplyStackList (ScreenInfo *screen_info)
 Client *
 clientGetLowestTransient (Client * c)
 {
-    Client *lowest_transient = NULL, *c2;
-    GList *index = NULL;
-    ScreenInfo *screen_info = NULL;
+    ScreenInfo *screen_info;
+    Client *lowest_transient, *c2;
+    GList *index;
 
     g_return_val_if_fail (c != NULL, NULL);
 
     TRACE ("entering clientGetLowestTransient");
 
+    lowest_transient = NULL;
     screen_info = c->screen_info;
     for (index = screen_info->windows_stack; index; index = g_list_next (index))
     {
@@ -95,15 +97,16 @@ clientGetLowestTransient (Client * c)
 Client *
 clientGetHighestTransientOrModalFor (Client * c)
 {
-    Client *highest_transient = NULL;
-    Client *c2 = NULL;
-    GList *index = NULL;
-    ScreenInfo *screen_info = NULL;
+    ScreenInfo *screen_info;
+    Client *highest_transient;
+    Client *c2;
+    GList *index;
 
     g_return_val_if_fail (c != NULL, NULL);
     TRACE ("entering clientGetHighestTransientOrModalFor");
 
     screen_info = c->screen_info;
+    highest_transient = NULL;
     for (index = screen_info->windows_stack; index; index = g_list_next (index))
     {
         c2 = (Client *) index->data;
@@ -122,15 +125,16 @@ clientGetHighestTransientOrModalFor (Client * c)
 Client *
 clientGetTopMostForGroup (Client * c)
 {
-    Client *top_most = NULL;
-    Client *c2 = NULL;
-    GList *index = NULL;
-    ScreenInfo *screen_info = NULL;
+    ScreenInfo *screen_info;
+    Client *top_most;
+    Client *c2;
+    GList *index;
 
     g_return_val_if_fail (c != NULL, NULL);
     TRACE ("entering clientGetTopMostForGroup");
 
     screen_info = c->screen_info;
+    top_most = NULL;
     for (index = screen_info->windows_stack; index; index = g_list_next (index))
     {
         c2 = (Client *) index->data;
@@ -146,14 +150,43 @@ clientGetTopMostForGroup (Client * c)
     return top_most;
 }
 
+gboolean
+clientIsTopMost (Client *c)
+{
+    ScreenInfo *screen_info;
+    GList *index;
+    
+    g_return_val_if_fail (c != NULL, FALSE);
+    TRACE ("entering clientIsTopMost");
+    
+    screen_info = c->screen_info;
+    
+    index = g_list_find (screen_info->windows_stack, (gconstpointer) c);
+    if (index)
+    {
+        GList *index2 = g_list_next (index);
+        if (index2)
+        {
+            Client *c2 = (Client *) index2->data;
+            return (c2->win_layer > c->win_layer);
+        }
+        else
+        {
+            return TRUE;
+        }
+    }
+    return FALSE;
+}
+
 Client *
 clientGetNextTopMost (ScreenInfo *screen_info, int layer, Client * exclude)
 {
-    Client *top = NULL, *c;
-    GList *index = NULL;
+    Client *top, *c;
+    GList *index;
 
     TRACE ("entering clientGetNextTopMost");
 
+    top = NULL;
     for (index = screen_info->windows_stack; index; index = g_list_next (index))
     {
         c = (Client *) index->data;
@@ -174,11 +207,12 @@ clientGetNextTopMost (ScreenInfo *screen_info, int layer, Client * exclude)
 Client *
 clientGetBottomMost (ScreenInfo *screen_info, int layer, Client * exclude)
 {
-    Client *bot = NULL, *c;
-    GList *index = NULL;
+    Client *bot, *c;
+    GList *index;
 
     TRACE ("entering clientGetBottomMost");
 
+    bot = NULL;
     for (index = screen_info->windows_stack; index; index = g_list_next (index))
     {
         c = (Client *) index->data;
@@ -202,25 +236,27 @@ clientGetBottomMost (ScreenInfo *screen_info, int layer, Client * exclude)
     return bot;
 }
 
+/*
+ * This function does the same as XQueryPointer but w/out the race
+ * conditions caused by querying the X server
+ */
 Client *
 clientAtPosition (ScreenInfo *screen_info, int x, int y, Client * exclude)
 {
-    /* This function does the same as XQueryPointer but w/out the race
-       conditions caused by querying the X server
-     */
-    GList *index = NULL;
-    Client *c = NULL;
-    Client *c2 = NULL;
+    GList *index;
+    Client *c, *c2;
 
-    TRACE ("entering clientAtPos");
+    TRACE ("entering clientAtPosition");
 
+    c = NULL;
     for (index = g_list_last (screen_info->windows_stack); index; index = g_list_previous (index))
     {
         c2 = (Client *) index->data;
-        if (clientSelectMask (c2, 0, WINDOW_NORMAL | WINDOW_DIALOG | WINDOW_MODAL_DIALOG) && (c2 != exclude))
+        if ((frameX (c2) < x) && (frameX (c2) + frameWidth (c2) > x)
+            && (frameY (c2) < y) && (frameY (c2) + frameHeight (c2) > y))
         {
-            if ((frameX (c2) < x) && (frameX (c2) + frameWidth (c2) > x)
-                && (frameY (c2) < y) && (frameY (c2) + frameHeight (c2) > y))
+            if (clientSelectMask (c2, 0, WINDOW_REGULAR_FOCUSABLE) 
+                && (c2 != exclude))
             {
                 c = c2;
                 break;
@@ -232,20 +268,52 @@ clientAtPosition (ScreenInfo *screen_info, int x, int y, Client * exclude)
 }
 
 void
-clientRaise (Client * c)
+clientRaise (Client * c, Window wsibling)
 {
-    ScreenInfo *screen_info = NULL;
+    ScreenInfo *screen_info;
+    DisplayInfo *display_info;
+    Client *c2, *c3, *client_sibling;
+    GList *transients;
+    GList *sibling;
+    GList *index1, *index2;
+    GList *windows_stack_copy;
 
     g_return_if_fail (c != NULL);
+
     TRACE ("entering clientRaise");
 
     screen_info = c->screen_info;
+    display_info = screen_info->display_info;
+    client_sibling = NULL;
+    transients = NULL;
+    sibling = NULL;
+
     if (c == screen_info->last_raise)
     {
         TRACE ("client \"%s\" (0x%lx) already raised", c->name, c->window);
         return;
     }
-    TRACE ("raising client \"%s\" (0x%lx)", c->name, c->window);
+    TRACE ("raising client \"%s\" (0x%lx) over (0x%lx)", c->name, c->window, wsibling);
+
+    /* 
+     * If the raised window is the one that has focus, fine, we can
+     * release the grab we have on it since there is no use for it
+     * anymore.
+     * 
+     * However, if the raised window is not the focused one, then we
+     * end up with some kind of indermination, so we need to regrab
+     * the buttons for the user to be able to raise or focus the window
+     * by clicking inside.
+     */
+
+    if (c == clientGetFocus ())
+    {
+        clientPassGrabMouseButton (c);
+    }
+    else
+    {
+        clientPassGrabMouseButton (NULL);
+    }
 
     if (g_list_length (screen_info->windows_stack) < 1)
     {
@@ -254,17 +322,34 @@ clientRaise (Client * c)
 
     if (FLAG_TEST (c->xfwm_flags, XFWM_FLAG_MANAGED))
     {
-        Client *c2, *c3;
-        Client *client_sibling = NULL;
-        GList *transients = NULL;
-        GList *sibling = NULL;
-        GList *index1, *index2;
-        GList *windows_stack_copy;
-
         /* Copy the existing window stack temporarily as reference */
         windows_stack_copy = g_list_copy (screen_info->windows_stack);
-        /* Search for the window that will be just on top of the raised window (layers...) */
-        client_sibling = clientGetNextTopMost (screen_info, c->win_layer, c);
+        /* Search for the window that will be just on top of the raised window  */
+        if (wsibling)
+        {
+            c2 = myDisplayGetClientFromWindow (display_info, wsibling, ANY);
+            if (c2)
+            {
+                sibling = g_list_find (screen_info->windows_stack, (gconstpointer) c2);
+                if (sibling)
+                {
+                    index1 = g_list_next (sibling);
+                    if (index1)
+                    {
+                        client_sibling = (Client *) index1->data;
+                        /* Do not place window under higher layers though */
+                        if ((client_sibling) && (client_sibling->win_layer < c->win_layer))
+                        {
+                            client_sibling = NULL;
+                        }
+                    }
+                }
+            }
+        }
+        if (!client_sibling)
+        {
+            client_sibling = clientGetNextTopMost (screen_info, c->win_layer, c);
+        }
         screen_info->windows_stack = g_list_remove (screen_info->windows_stack, (gconstpointer) c);
         if (client_sibling)
         {
@@ -284,7 +369,7 @@ clientRaise (Client * c)
             c2 = (Client *) index1->data;
             if (c2)
             {
-                if ((c2 != c) && clientIsTransientOrModalFor (c2, c))
+                if ((c2 != c) && clientIsTransientOrModalFor (c2, c) && (c2->win_layer <= c->win_layer))
                 {
                     transients = g_list_append (transients, c2);
                     if (sibling)
@@ -346,21 +431,32 @@ clientRaise (Client * c)
            We still need to tell the X Server to reflect the changes
          */
         clientApplyStackList (screen_info);
-        clientSetNetClientList (c->screen_info, net_client_list_stacking, screen_info->windows_stack);
+        clientSetNetClientList (c->screen_info, display_info->atoms[NET_CLIENT_LIST_STACKING], screen_info->windows_stack);
         screen_info->last_raise = c;
     }
 }
 
 void
-clientLower (Client * c)
+clientLower (Client * c, Window wsibling)
 {
-    ScreenInfo *screen_info = NULL;
+    ScreenInfo *screen_info;
+    DisplayInfo *display_info;
+    Client *c2, *client_sibling;
+    GList *sibling;
+    GList *index;
+    gint position;
 
     g_return_if_fail (c != NULL);
+
     TRACE ("entering clientLower");
-    TRACE ("lowering client \"%s\" (0x%lx)", c->name, c->window);
+    TRACE ("lowering client \"%s\" (0x%lx) below (0x%lx)", c->name, c->window, wsibling);
 
     screen_info = c->screen_info;
+    display_info = screen_info->display_info;
+    client_sibling = NULL;
+    sibling = NULL;
+    c2 = NULL;
+
     if (g_list_length (screen_info->windows_stack) < 1)
     {
         return;
@@ -368,8 +464,6 @@ clientLower (Client * c)
 
     if (FLAG_TEST (c->xfwm_flags, XFWM_FLAG_MANAGED))
     {
-        Client *client_sibling = NULL;
-
         if (clientIsTransientOrModalForGroup (c))
         {
             client_sibling = clientGetTopMostForGroup (c);
@@ -378,7 +472,29 @@ clientLower (Client * c)
         {
             client_sibling = clientGetTransient (c);
         }
-        if (!client_sibling)
+        else if (wsibling)
+        {
+            c2 = myDisplayGetClientFromWindow (display_info, wsibling, ANY);
+            if (c2)
+            {
+                sibling = g_list_find (screen_info->windows_stack, (gconstpointer) c2);
+                if (sibling)
+                {
+                    index = g_list_previous (sibling);
+                    if (index)
+                    {
+                        client_sibling = (Client *) index->data;
+                        /* Do not place window above lower layers though */
+                        if ((client_sibling) && (client_sibling->win_layer > c->win_layer))
+                        {
+                            client_sibling = NULL;
+                        }
+                    }
+                }
+            }
+        }
+        if ((!client_sibling) || 
+            (client_sibling && (client_sibling->win_layer < c->win_layer)))
         {
             client_sibling = clientGetBottomMost (screen_info, c->win_layer, c);
         }
@@ -388,8 +504,8 @@ clientLower (Client * c)
             /* Paranoid check to avoid circular linked list */
             if (client_sibling)
             {
-                GList *sibling = g_list_find (screen_info->windows_stack, (gconstpointer) client_sibling);
-                gint position = g_list_position (screen_info->windows_stack, sibling) + 1;
+                sibling = g_list_find (screen_info->windows_stack, (gconstpointer) client_sibling);
+                position = g_list_position (screen_info->windows_stack, sibling) + 1;
 
                 screen_info->windows_stack = g_list_insert (screen_info->windows_stack, c, position);
                 TRACE ("lowest client is \"%s\" (0x%lx) at position %i",
@@ -404,7 +520,8 @@ clientLower (Client * c)
            We still need to tell the X Server to reflect the changes
          */
         clientApplyStackList (screen_info);
-        clientSetNetClientList (screen_info, net_client_list_stacking, screen_info->windows_stack);
+        clientSetNetClientList (screen_info, display_info->atoms[NET_CLIENT_LIST_STACKING], screen_info->windows_stack);
+        clientPassGrabMouseButton (NULL);
         clientPassFocus (screen_info, c, NULL);
         if (screen_info->last_raise == c)
         {
@@ -449,8 +566,8 @@ clientAdjustFullscreenLayer (Client *c, gboolean set)
 void
 clientAddToList (Client * c)
 {
-    ScreenInfo *screen_info = NULL;
-    DisplayInfo *display_info = NULL;
+    ScreenInfo *screen_info;
+    DisplayInfo *display_info;
 
     g_return_if_fail (c != NULL);
     TRACE ("entering clientAddToList");
@@ -478,9 +595,8 @@ clientAddToList (Client * c)
     screen_info->windows = g_list_append (screen_info->windows, c);
     screen_info->windows_stack = g_list_append (screen_info->windows_stack, c);
 
-    clientSetNetClientList (screen_info, net_client_list, screen_info->windows);
-    clientSetNetClientList (screen_info, win_client_list, screen_info->windows);
-    clientSetNetClientList (screen_info, net_client_list_stacking, screen_info->windows_stack);
+    clientSetNetClientList (screen_info, display_info->atoms[NET_CLIENT_LIST], screen_info->windows);
+    clientSetNetClientList (screen_info, display_info->atoms[WIN_CLIENT_LIST], screen_info->windows);
 
     FLAG_SET (c->xfwm_flags, XFWM_FLAG_MANAGED);
 }
@@ -488,8 +604,8 @@ clientAddToList (Client * c)
 void
 clientRemoveFromList (Client * c)
 {
-    ScreenInfo *screen_info = NULL;
-    DisplayInfo *display_info = NULL;
+    ScreenInfo *screen_info;
+    DisplayInfo *display_info;
 
     g_return_if_fail (c != NULL);
     TRACE ("entering clientRemoveFromList");
@@ -522,9 +638,9 @@ clientRemoveFromList (Client * c)
     TRACE ("removing window \"%s\" (0x%lx) from screen_info->windows_stack list", c->name, c->window);
     screen_info->windows_stack = g_list_remove (screen_info->windows_stack, c);
 
-    clientSetNetClientList (screen_info, net_client_list, screen_info->windows);
-    clientSetNetClientList (screen_info, win_client_list, screen_info->windows);
-    clientSetNetClientList (screen_info, net_client_list_stacking, screen_info->windows_stack);
+    clientSetNetClientList (screen_info, display_info->atoms[NET_CLIENT_LIST], screen_info->windows);
+    clientSetNetClientList (screen_info, display_info->atoms[WIN_CLIENT_LIST], screen_info->windows);
+    clientSetNetClientList (screen_info, display_info->atoms[NET_CLIENT_LIST_STACKING], screen_info->windows_stack);
 
     FLAG_UNSET (c->xfwm_flags, XFWM_FLAG_MANAGED);
 }
@@ -532,21 +648,19 @@ clientRemoveFromList (Client * c)
 GList *
 clientGetStackList (ScreenInfo *screen_info)
 {
-    GList *windows_stack_copy = NULL;
-
     g_return_val_if_fail (screen_info, NULL);
 
     if (screen_info->windows_stack)
     {
-        windows_stack_copy = g_list_copy (screen_info->windows_stack);
+        return g_list_copy (screen_info->windows_stack);
     }
-    return windows_stack_copy;
+    return NULL;
 }
 
 void
 clientSetLastRaise (Client *c)
 {
-    ScreenInfo *screen_info = NULL;
+    ScreenInfo *screen_info;
 
     g_return_if_fail (c != NULL);
 
